@@ -125,7 +125,7 @@ async def _purge_helper(
     before: Optional[SnowflakeTime] = None,
     after: Optional[SnowflakeTime] = None,
     around: Optional[SnowflakeTime] = None,
-    oldest_first: Optional[bool] = False,
+    oldest_first: Optional[bool] = None,
     bulk: bool = True,
     reason: Optional[str] = None,
 ) -> List[Message]:
