@@ -31,7 +31,7 @@ import collections.abc
 import inspect
 import importlib.util
 import sys
-import traceback
+import logging
 import types
 from typing import (
     Any,
@@ -95,6 +95,8 @@ __all__ = (
 T = TypeVar('T')
 CFT = TypeVar('CFT', bound='CoroFunc')
 
+_log = logging.getLogger(__name__)
+
 
 def when_mentioned(bot: _Bot, msg: Message, /) -> List[str]:
     """A callable that implements a command prefix equivalent to being mentioned.
@@ -304,7 +306,7 @@ class BotBase(GroupMixin[None]):
 
         The default command error handler provided by the bot.
 
-        By default this prints to :data:`sys.stderr` however it could be
+        By default this logs to the library logger, however it could be
         overridden to have a different implementation.
 
         This only fires if you do not specify any listeners for command error.
@@ -312,6 +314,7 @@ class BotBase(GroupMixin[None]):
         .. versionchanged:: 2.0
 
             ``context`` and ``exception`` parameters are now positional-only.
+            Instead of writing to ``sys.stderr`` this now uses the library logger.
         """
         if self.extra_events.get('on_command_error', None):
             return
@@ -324,8 +327,7 @@ class BotBase(GroupMixin[None]):
         if cog and cog.has_error_handler():
             return
 
-        print(f'Ignoring exception in command {context.command}:', file=sys.stderr)
-        traceback.print_exception(type(exception), exception, exception.__traceback__, file=sys.stderr)
+        _log.error('Ignoring exception in command %s', command, exc_info=exception)
 
     # global check registration
 
@@ -460,8 +462,7 @@ class BotBase(GroupMixin[None]):
         if len(data) == 0:
             return True
 
-        # type-checker doesn't distinguish between functions and methods
-        return await discord.utils.async_all(f(ctx) for f in data)  # type: ignore
+        return await discord.utils.async_all(f(ctx) for f in data)
 
     async def is_owner(self, user: User, /) -> bool:
         """|coro|
@@ -1388,6 +1389,14 @@ class Bot(BotBase, discord.Client):
     a :class:`~discord.app_commands.CommandTree` and is automatically set upon
     instantiating the class.
 
+    .. container:: operations
+
+        .. describe:: async with x
+
+            Asynchronously initialises the bot and automatically cleans up.
+
+            .. versionadded:: 2.0
+
     Attributes
     -----------
     command_prefix
@@ -1458,6 +1467,14 @@ class Bot(BotBase, discord.Client):
 class AutoShardedBot(BotBase, discord.AutoShardedClient):
     """This is similar to :class:`.Bot` except that it is inherited from
     :class:`discord.AutoShardedClient` instead.
+
+    .. container:: operations
+
+        .. describe:: async with x
+
+            Asynchronously initialises the bot and automatically cleans.
+
+            .. versionadded:: 2.0
     """
 
     pass
